@@ -1,3 +1,4 @@
+import json
 import logging
 from dataclasses import dataclass
 from typing import List
@@ -16,7 +17,8 @@ logger.setLevel(logging.INFO)
 class IngestionApiConfig:
     url: str
     api_key: str
-    timeout: int = 3  # default 3 seconds timeout
+    batch_size: int = 20
+    timeout: int = 30  # default 30 seconds timeout
 
 
 class IngestionApi(Sink):
@@ -25,26 +27,32 @@ class IngestionApi(Sink):
     def __init__(self, config: IngestionApiConfig):
         self._url = config.url
         self._post_header = {"x-api-key": config.api_key}
+        self._batch_size = config.batch_size
         self._timeout = config.timeout
 
     def _sink(self, messages: List[dict]) -> None:
         """Post messages to Ingestion API"""
-        for message in messages:
+        for chunk in self._chunks(messages, self._batch_size):
             response = None
             try:
                 response = post(
                     self._url,
-                    json=message,
+                    json=chunk,
                     headers=self._post_header,
                     timeout=self._timeout,
                 )
 
                 # If the response was successful, no Exception will be raised
                 response.raise_for_status()
-                logger.debug(f"POST response {response.text}")
+                logger.info(f"Posted {len(chunk)} messages")
+                logger.debug(f"POST response {json.dumps(response.text)}")
             except HTTPError as http_error:
-                logger.error(f"HTTP error {http_error}, response {response.text}")
+                logger.error(
+                    f"HTTP error {http_error}, response {json.dumps(response.text) if response is not None else ''}"
+                )
             except Exception as error:
-                logger.error(f"POST error: {error}, response {response.text}")
+                logger.error(
+                    f"POST error: {error}, response {json.dumps(response.text) if response is not None else ''}"
+                )
 
-        logger.info(f"Posted {len(messages)} messages")
+        logger.info(f"Posted total {len(messages)} messages")
