@@ -10,20 +10,20 @@
 #
 #     result = metadata_change_event_from_dict(json.loads(json_string))
 
-from enum import Enum
 from dataclasses import dataclass
-from typing import Optional, Any, List, TypeVar, Type, cast, Callable
 from datetime import datetime
-import dateutil.parser
+from enum import Enum
+from typing import Any, Callable, List, Optional, Type, TypeVar, cast
 
+import dateutil.parser
 
 T = TypeVar("T")
 EnumT = TypeVar("EnumT", bound=Enum)
 
 
-def from_str(x: Any) -> str:
-    assert isinstance(x, str)
-    return x
+def from_float(x: Any) -> float:
+    assert isinstance(x, (float, int)) and not isinstance(x, bool)
+    return float(x)
 
 
 def from_none(x: Any) -> Any:
@@ -40,17 +40,17 @@ def from_union(fs, x):
     assert False
 
 
+def to_float(x: Any) -> float:
+    assert isinstance(x, float)
+    return x
+
+
 def from_datetime(x: Any) -> datetime:
     return dateutil.parser.parse(x)
 
 
-def from_float(x: Any) -> float:
-    assert isinstance(x, (float, int)) and not isinstance(x, bool)
-    return float(x)
-
-
-def to_float(x: Any) -> float:
-    assert isinstance(x, float)
+def from_str(x: Any) -> str:
+    assert isinstance(x, str)
     return x
 
 
@@ -75,6 +75,7 @@ def from_list(f: Callable[[Any], T], x: Any) -> List[T]:
 
 
 class AspectType(Enum):
+    DASHBOARD_INFO = "DASHBOARD_INFO"
     DATASET_COMMENT = "DATASET_COMMENT"
     DATASET_DOCUMENTATION = "DATASET_DOCUMENTATION"
     DATASET_DOWNSTREAM = "DATASET_DOWNSTREAM"
@@ -84,9 +85,144 @@ class AspectType(Enum):
     GROUP_INFO = "GROUP_INFO"
     OWNERSHIP = "OWNERSHIP"
     PERSON_EDITABLE_INFO = "PERSON_EDITABLE_INFO"
+    PERSON_ORGANIZATION = "PERSON_ORGANIZATION"
+    PERSON_PROPERTIES = "PERSON_PROPERTIES"
     PROPERTIES = "PROPERTIES"
 
 
+@dataclass
+class ObjectID:
+    """A class representation of the BSON ObjectId type."""
+    """The generation time of this ObjectId instance"""
+    generation_time: Optional[float] = None
+
+    @staticmethod
+    def from_dict(obj: Any) -> 'ObjectID':
+        assert isinstance(obj, dict)
+        generation_time = from_union([from_float, from_none], obj.get("generationTime"))
+        return ObjectID(generation_time)
+
+    def to_dict(self) -> dict:
+        result: dict = {}
+        result["generationTime"] = from_union([to_float, from_none], self.generation_time)
+        return result
+
+
+@dataclass
+class DashboardInfo:
+    id: Optional[ObjectID] = None
+    aspect_type: Optional[AspectType] = None
+    created_at: Optional[datetime] = None
+    description: Optional[str] = None
+    entity_id: Optional[str] = None
+    dashboard_info_id: Optional[str] = None
+    latest: Optional[bool] = None
+    title: Optional[str] = None
+
+    @staticmethod
+    def from_dict(obj: Any) -> 'DashboardInfo':
+        assert isinstance(obj, dict)
+        id = from_union([ObjectID.from_dict, from_none], obj.get("_id"))
+        aspect_type = from_union([AspectType, from_none], obj.get("aspectType"))
+        created_at = from_union([from_datetime, from_none], obj.get("createdAt"))
+        description = from_union([from_str, from_none], obj.get("description"))
+        entity_id = from_union([from_str, from_none], obj.get("entityId"))
+        dashboard_info_id = from_union([from_str, from_none], obj.get("id"))
+        latest = from_union([from_bool, from_none], obj.get("latest"))
+        title = from_union([from_str, from_none], obj.get("title"))
+        return DashboardInfo(id, aspect_type, created_at, description, entity_id, dashboard_info_id, latest, title)
+
+    def to_dict(self) -> dict:
+        result: dict = {}
+        result["_id"] = from_union([lambda x: to_class(ObjectID, x), from_none], self.id)
+        result["aspectType"] = from_union([lambda x: to_enum(AspectType, x), from_none], self.aspect_type)
+        result["createdAt"] = from_union([lambda x: x.isoformat(), from_none], self.created_at)
+        result["description"] = from_union([from_str, from_none], self.description)
+        result["entityId"] = from_union([from_str, from_none], self.entity_id)
+        result["id"] = from_union([from_str, from_none], self.dashboard_info_id)
+        result["latest"] = from_union([from_bool, from_none], self.latest)
+        result["title"] = from_union([from_str, from_none], self.title)
+        return result
+
+
+class EntityType(Enum):
+    DASHBOARD = "DASHBOARD"
+    DATASET = "DATASET"
+    GROUP = "GROUP"
+    PERSON = "PERSON"
+    PROJECT = "PROJECT"
+
+
+class DashboardPlatform(Enum):
+    LOOKER = "LOOKER"
+    UNKNOWN = "UNKNOWN"
+
+
+@dataclass
+class DashboardLogicalID:
+    """Identify an entity "logically", besides the system generated UUID.
+    Each entity must have a logicalId to be ingested.
+    A compelling use-case is that this allows a producer to create an
+    instance of the Entity without requiring a unique UUID to be
+    obtained prior to instantiation, potentially resulting in two round-trips
+    """
+    dashboard_id: Optional[str] = None
+    platform: Optional[DashboardPlatform] = None
+
+    @staticmethod
+    def from_dict(obj: Any) -> 'DashboardLogicalID':
+        assert isinstance(obj, dict)
+        dashboard_id = from_union([from_str, from_none], obj.get("dashboardId"))
+        platform = from_union([DashboardPlatform, from_none], obj.get("platform"))
+        return DashboardLogicalID(dashboard_id, platform)
+
+    def to_dict(self) -> dict:
+        result: dict = {}
+        result["dashboardId"] = from_union([from_str, from_none], self.dashboard_id)
+        result["platform"] = from_union([lambda x: to_enum(DashboardPlatform, x), from_none], self.platform)
+        return result
+
+
+@dataclass
+class Dashboard:
+    created_at: Optional[datetime] = None
+    dashboard_info: Optional[DashboardInfo] = None
+    deleted_at: Optional[datetime] = None
+    entity_type: Optional[EntityType] = None
+    id: Optional[str] = None
+    last_modified_at: Optional[datetime] = None
+    """Identify an entity "logically", besides the system generated UUID.
+    Each entity must have a logicalId to be ingested.
+    A compelling use-case is that this allows a producer to create an
+    instance of the Entity without requiring a unique UUID to be
+    obtained prior to instantiation, potentially resulting in two round-trips
+    """
+    logical_id: Optional[DashboardLogicalID] = None
+
+    @staticmethod
+    def from_dict(obj: Any) -> 'Dashboard':
+        assert isinstance(obj, dict)
+        created_at = from_union([from_datetime, from_none], obj.get("createdAt"))
+        dashboard_info = from_union([DashboardInfo.from_dict, from_none], obj.get("dashboardInfo"))
+        deleted_at = from_union([from_datetime, from_none], obj.get("deletedAt"))
+        entity_type = from_union([EntityType, from_none], obj.get("entityType"))
+        id = from_union([from_str, from_none], obj.get("id"))
+        last_modified_at = from_union([from_datetime, from_none], obj.get("lastModifiedAt"))
+        logical_id = from_union([DashboardLogicalID.from_dict, from_none], obj.get("logicalId"))
+        return Dashboard(created_at, dashboard_info, deleted_at, entity_type, id, last_modified_at, logical_id)
+
+    def to_dict(self) -> dict:
+        result: dict = {}
+        result["createdAt"] = from_union([lambda x: x.isoformat(), from_none], self.created_at)
+        result["dashboardInfo"] = from_union([lambda x: to_class(DashboardInfo, x), from_none], self.dashboard_info)
+        result["deletedAt"] = from_union([lambda x: x.isoformat(), from_none], self.deleted_at)
+        result["entityType"] = from_union([lambda x: to_enum(EntityType, x), from_none], self.entity_type)
+        result["id"] = from_union([from_str, from_none], self.id)
+        result["lastModifiedAt"] = from_union([lambda x: x.isoformat(), from_none], self.last_modified_at)
+        result["logicalId"] = from_union([lambda x: to_class(DashboardLogicalID, x), from_none], self.logical_id)
+        return result
+
+
 @dataclass
 class AuditStamp:
     actor: Optional[str] = None
@@ -106,24 +242,6 @@ class AuditStamp:
         return result
 
 
-@dataclass
-class ObjectID:
-    """A class representation of the BSON ObjectId type."""
-    """The generation time of this ObjectId instance"""
-    generation_time: Optional[float] = None
-
-    @staticmethod
-    def from_dict(obj: Any) -> 'ObjectID':
-        assert isinstance(obj, dict)
-        generation_time = from_union([from_float, from_none], obj.get("generationTime"))
-        return ObjectID(generation_time)
-
-    def to_dict(self) -> dict:
-        result: dict = {}
-        result["generationTime"] = from_union([to_float, from_none], self.generation_time)
-        return result
-
-
 @dataclass
 class DatasetComment:
     id: Optional[ObjectID] = None
@@ -275,7 +393,7 @@ class DatasetDownstream:
     id: Optional[ObjectID] = None
     aspect_type: Optional[AspectType] = None
     created_at: Optional[datetime] = None
-    datasets: Optional[List[DatasetLogicalID]] = None
+    destinations: Optional[List[DatasetLogicalID]] = None
     entity_id: Optional[str] = None
     dataset_downstream_id: Optional[str] = None
     latest: Optional[bool] = None
@@ -286,32 +404,24 @@ class DatasetDownstream:
         id = from_union([ObjectID.from_dict, from_none], obj.get("_id"))
         aspect_type = from_union([AspectType, from_none], obj.get("aspectType"))
         created_at = from_union([from_datetime, from_none], obj.get("createdAt"))
-        datasets = from_union([lambda x: from_list(DatasetLogicalID.from_dict, x), from_none], obj.get("datasets"))
+        destinations = from_union([lambda x: from_list(DatasetLogicalID.from_dict, x), from_none], obj.get("destinations"))
         entity_id = from_union([from_str, from_none], obj.get("entityId"))
         dataset_downstream_id = from_union([from_str, from_none], obj.get("id"))
         latest = from_union([from_bool, from_none], obj.get("latest"))
-        return DatasetDownstream(id, aspect_type, created_at, datasets, entity_id, dataset_downstream_id, latest)
+        return DatasetDownstream(id, aspect_type, created_at, destinations, entity_id, dataset_downstream_id, latest)
 
     def to_dict(self) -> dict:
         result: dict = {}
         result["_id"] = from_union([lambda x: to_class(ObjectID, x), from_none], self.id)
         result["aspectType"] = from_union([lambda x: to_enum(AspectType, x), from_none], self.aspect_type)
         result["createdAt"] = from_union([lambda x: x.isoformat(), from_none], self.created_at)
-        result["datasets"] = from_union([lambda x: from_list(lambda x: to_class(DatasetLogicalID, x), x), from_none], self.datasets)
+        result["destinations"] = from_union([lambda x: from_list(lambda x: to_class(DatasetLogicalID, x), x), from_none], self.destinations)
         result["entityId"] = from_union([from_str, from_none], self.entity_id)
         result["id"] = from_union([from_str, from_none], self.dataset_downstream_id)
         result["latest"] = from_union([from_bool, from_none], self.latest)
         return result
 
 
-class EntityType(Enum):
-    DASHBOARD = "DASHBOARD"
-    DATASET = "DATASET"
-    GROUP = "GROUP"
-    PERSON = "PERSON"
-    PROJECT = "PROJECT"
-
-
 @dataclass
 class GroupID:
     """Identify an entity "logically", besides the system generated UUID.
@@ -583,6 +693,7 @@ class DatasetSchema:
     id: Optional[ObjectID] = None
     aspect_type: Optional[AspectType] = None
     created_at: Optional[datetime] = None
+    description: Optional[str] = None
     entity_id: Optional[str] = None
     fields: Optional[List[SchemaField]] = None
     dataset_schema_id: Optional[str] = None
@@ -597,6 +708,7 @@ class DatasetSchema:
         id = from_union([ObjectID.from_dict, from_none], obj.get("_id"))
         aspect_type = from_union([AspectType, from_none], obj.get("aspectType"))
         created_at = from_union([from_datetime, from_none], obj.get("createdAt"))
+        description = from_union([from_str, from_none], obj.get("description"))
         entity_id = from_union([from_str, from_none], obj.get("entityId"))
         fields = from_union([lambda x: from_list(SchemaField.from_dict, x), from_none], obj.get("fields"))
         dataset_schema_id = from_union([from_str, from_none], obj.get("id"))
@@ -604,13 +716,14 @@ class DatasetSchema:
         latest = from_union([from_bool, from_none], obj.get("latest"))
         schema_type = from_union([SchemaType, from_none], obj.get("schemaType"))
         sql_schema = from_union([SQLSchema.from_dict, from_none], obj.get("sqlSchema"))
-        return DatasetSchema(id, aspect_type, created_at, entity_id, fields, dataset_schema_id, last_modified, latest, schema_type, sql_schema)
+        return DatasetSchema(id, aspect_type, created_at, description, entity_id, fields, dataset_schema_id, last_modified, latest, schema_type, sql_schema)
 
     def to_dict(self) -> dict:
         result: dict = {}
         result["_id"] = from_union([lambda x: to_class(ObjectID, x), from_none], self.id)
         result["aspectType"] = from_union([lambda x: to_enum(AspectType, x), from_none], self.aspect_type)
         result["createdAt"] = from_union([lambda x: x.isoformat(), from_none], self.created_at)
+        result["description"] = from_union([from_str, from_none], self.description)
         result["entityId"] = from_union([from_str, from_none], self.entity_id)
         result["fields"] = from_union([lambda x: from_list(lambda x: to_class(SchemaField, x), x), from_none], self.fields)
         result["id"] = from_union([from_str, from_none], self.dataset_schema_id)
@@ -923,6 +1036,85 @@ class Group:
         return result
 
 
+@dataclass
+class PersonProperties:
+    id: Optional[ObjectID] = None
+    aspect_type: Optional[AspectType] = None
+    avatar_url: Optional[str] = None
+    created_at: Optional[datetime] = None
+    department: Optional[str] = None
+    display_name: Optional[str] = None
+    division: Optional[str] = None
+    employee_number: Optional[str] = None
+    entity_id: Optional[str] = None
+    first_name: Optional[str] = None
+    person_properties_id: Optional[str] = None
+    last_login: Optional[str] = None
+    last_name: Optional[str] = None
+    latest: Optional[bool] = None
+    manager: Optional[str] = None
+    manager_id: Optional[str] = None
+    mobile_phone: Optional[str] = None
+    occupation: Optional[str] = None
+    organization: Optional[str] = None
+    primary_phone: Optional[str] = None
+    status: Optional[str] = None
+    title: Optional[str] = None
+
+    @staticmethod
+    def from_dict(obj: Any) -> 'PersonProperties':
+        assert isinstance(obj, dict)
+        id = from_union([ObjectID.from_dict, from_none], obj.get("_id"))
+        aspect_type = from_union([AspectType, from_none], obj.get("aspectType"))
+        avatar_url = from_union([from_str, from_none], obj.get("avatarUrl"))
+        created_at = from_union([from_datetime, from_none], obj.get("createdAt"))
+        department = from_union([from_str, from_none], obj.get("department"))
+        display_name = from_union([from_str, from_none], obj.get("displayName"))
+        division = from_union([from_str, from_none], obj.get("division"))
+        employee_number = from_union([from_str, from_none], obj.get("employeeNumber"))
+        entity_id = from_union([from_str, from_none], obj.get("entityId"))
+        first_name = from_union([from_str, from_none], obj.get("firstName"))
+        person_properties_id = from_union([from_str, from_none], obj.get("id"))
+        last_login = from_union([from_str, from_none], obj.get("lastLogin"))
+        last_name = from_union([from_str, from_none], obj.get("lastName"))
+        latest = from_union([from_bool, from_none], obj.get("latest"))
+        manager = from_union([from_str, from_none], obj.get("manager"))
+        manager_id = from_union([from_str, from_none], obj.get("managerId"))
+        mobile_phone = from_union([from_str, from_none], obj.get("mobilePhone"))
+        occupation = from_union([from_str, from_none], obj.get("occupation"))
+        organization = from_union([from_str, from_none], obj.get("organization"))
+        primary_phone = from_union([from_str, from_none], obj.get("primaryPhone"))
+        status = from_union([from_str, from_none], obj.get("status"))
+        title = from_union([from_str, from_none], obj.get("title"))
+        return PersonProperties(id, aspect_type, avatar_url, created_at, department, display_name, division, employee_number, entity_id, first_name, person_properties_id, last_login, last_name, latest, manager, manager_id, mobile_phone, occupation, organization, primary_phone, status, title)
+
+    def to_dict(self) -> dict:
+        result: dict = {}
+        result["_id"] = from_union([lambda x: to_class(ObjectID, x), from_none], self.id)
+        result["aspectType"] = from_union([lambda x: to_enum(AspectType, x), from_none], self.aspect_type)
+        result["avatarUrl"] = from_union([from_str, from_none], self.avatar_url)
+        result["createdAt"] = from_union([lambda x: x.isoformat(), from_none], self.created_at)
+        result["department"] = from_union([from_str, from_none], self.department)
+        result["displayName"] = from_union([from_str, from_none], self.display_name)
+        result["division"] = from_union([from_str, from_none], self.division)
+        result["employeeNumber"] = from_union([from_str, from_none], self.employee_number)
+        result["entityId"] = from_union([from_str, from_none], self.entity_id)
+        result["firstName"] = from_union([from_str, from_none], self.first_name)
+        result["id"] = from_union([from_str, from_none], self.person_properties_id)
+        result["lastLogin"] = from_union([from_str, from_none], self.last_login)
+        result["lastName"] = from_union([from_str, from_none], self.last_name)
+        result["latest"] = from_union([from_bool, from_none], self.latest)
+        result["manager"] = from_union([from_str, from_none], self.manager)
+        result["managerId"] = from_union([from_str, from_none], self.manager_id)
+        result["mobilePhone"] = from_union([from_str, from_none], self.mobile_phone)
+        result["occupation"] = from_union([from_str, from_none], self.occupation)
+        result["organization"] = from_union([from_str, from_none], self.organization)
+        result["primaryPhone"] = from_union([from_str, from_none], self.primary_phone)
+        result["status"] = from_union([from_str, from_none], self.status)
+        result["title"] = from_union([from_str, from_none], self.title)
+        return result
+
+
 @dataclass
 class Person:
     """A person entity represents any individual who is a member of the organization (or beyond)
@@ -945,6 +1137,7 @@ class Person:
     """
     logical_id: Optional[PersonID] = None
     password: Optional[str] = None
+    properties: Optional[PersonProperties] = None
 
     @staticmethod
     def from_dict(obj: Any) -> 'Person':
@@ -959,7 +1152,8 @@ class Person:
         last_name = from_union([from_str, from_none], obj.get("lastName"))
         logical_id = from_union([PersonID.from_dict, from_none], obj.get("logicalId"))
         password = from_union([from_str, from_none], obj.get("password"))
-        return Person(avatar_url, created_at, deleted_at, entity_type, first_name, id, last_modified_at, last_name, logical_id, password)
+        properties = from_union([PersonProperties.from_dict, from_none], obj.get("properties"))
+        return Person(avatar_url, created_at, deleted_at, entity_type, first_name, id, last_modified_at, last_name, logical_id, password, properties)
 
     def to_dict(self) -> dict:
         result: dict = {}
@@ -973,11 +1167,13 @@ class Person:
         result["lastName"] = from_union([from_str, from_none], self.last_name)
         result["logicalId"] = from_union([lambda x: to_class(PersonID, x), from_none], self.logical_id)
         result["password"] = from_union([from_str, from_none], self.password)
+        result["properties"] = from_union([lambda x: to_class(PersonProperties, x), from_none], self.properties)
         return result
 
 
 @dataclass
 class MetadataChangeEvent:
+    dashboard: Optional[Dashboard] = None
     dataset: Optional[Dataset] = None
     event_header: Optional[EventHeader] = None
     group: Optional[Group] = None
@@ -991,15 +1187,17 @@ class MetadataChangeEvent:
     @staticmethod
     def from_dict(obj: Any) -> 'MetadataChangeEvent':
         assert isinstance(obj, dict)
+        dashboard = from_union([Dashboard.from_dict, from_none], obj.get("dashboard"))
         dataset = from_union([Dataset.from_dict, from_none], obj.get("dataset"))
         event_header = from_union([EventHeader.from_dict, from_none], obj.get("eventHeader"))
         group = from_union([Group.from_dict, from_none], obj.get("group"))
         person = from_union([Person.from_dict, from_none], obj.get("person"))
         tenant = from_union([from_str, from_none], obj.get("tenant"))
-        return MetadataChangeEvent(dataset, event_header, group, person, tenant)
+        return MetadataChangeEvent(dashboard, dataset, event_header, group, person, tenant)
 
     def to_dict(self) -> dict:
         result: dict = {}
+        result["dashboard"] = from_union([lambda x: to_class(Dashboard, x), from_none], self.dashboard)
         result["dataset"] = from_union([lambda x: to_class(Dataset, x), from_none], self.dataset)
         result["eventHeader"] = from_union([lambda x: to_class(EventHeader, x), from_none], self.event_header)
         result["group"] = from_union([lambda x: to_class(Group, x), from_none], self.group)
