@@ -1,7 +1,7 @@
 import json
 import logging
 from abc import ABC, abstractmethod
-from typing import List
+from typing import Generator, List
 
 from .event_util import EventUtil
 from .metadata_change_event import MetadataChangeEvent
@@ -21,6 +21,12 @@ class Sink(ABC):
         if valid_records:
             self._sink(valid_records)
 
+    @staticmethod
+    def _chunks(records: List, n: int) -> Generator[List, None, None]:
+        """Yield successive n-sized chunks from list."""
+        for i in range(0, len(records), n):
+            yield records[i : i + n]
+
     @abstractmethod
-    async def _sink(self, messages: List[dict]) -> None:
+    def _sink(self, messages: List[dict]) -> None:
         """Sink metadata records to ingestion pipeline, should be overridden"""
