@@ -2,7 +2,7 @@ import json
 import logging
 import re
 from dataclasses import dataclass
-from datetime import datetime
+from datetime import datetime, timezone
 from typing import Dict, List, Optional
 
 from dataclasses_json import dataclass_json
@@ -196,9 +196,11 @@ class DbtExtractor(BaseExtractor):
             dataset.statistics.data_size = (
                 float(stats["bytes"]["value"]) / 1048576  # convert bytes to MB
             )
+
+            # Must set tzinfo explicitly due to https://bugs.python.org/issue22377
             dataset.statistics.last_updated = datetime.strptime(
                 stats["last_modified"]["value"], "%Y-%m-%d %H:%M%Z"
-            )
+            ).replace(tzinfo=timezone.utc)
 
     @staticmethod
     def _dataset_name(db: str, schema: str, table: str) -> str:
